﻿namespace EndMove.Sudoku.Solver.Core.Algorithms;

public interface ISolver
{
    /// <summary>
    /// Check if a number is valid in a cell
    /// </summary>
    /// <param name="board">The sudoku board (2D Board)</param>
    /// <param name="row">New number in x</param>
    /// <param name="col">New number in y</param>
    /// <param name="n">New number value</param>
    /// <returns>True if valid, False otherwise</returns>
    public bool IsValid(int[,] board, int row, int col, int n);

    /// <summary>
    /// Check if a number is valid in a cell
    /// </summary>
    /// <param name="board">The sudoku board (1D Board)</param>
    /// <param name="row">New number in x</param>
    /// <param name="col">New number in y</param>
    /// <param name="n">New number value</param>
    /// <returns>True if valid, False otherwise</returns>
    public bool IsValid(int[] board, int row, int col, int n);

    /// <summary>
    /// Solve the sudoku board
    /// </summary>
    /// <param name="board">Initial board</param>
    /// <returns>Is solved, solved board</returns>
    public (bool, int[,]) Solve(int[,] board);

    /// <summary>
    /// Solve the sudoku board with a 1D array
    /// </summary>
    /// <param name="board">Initial board</param>
    /// <returns>Is solved, solved board</returns>
    public (bool, int[]) Solve(int[] board);
}